import React, { useCallback, useEffect, useState } from 'react'
import { MenuItem, SelectButton, SelectMenuElementProps } from '../common'
import { MediaDeviceManager } from '@zocks-communications/client-sdk-js'

export const DeviceSelectButton: React.FC<{
  deviceKind: MediaDeviceKind
  onDeviceSelected: (mediaDeviceInfo: MediaDeviceInfo) => void
  disabled?: boolean
  className?: string
  label?: string
  selectMenuElement?: React.FC<SelectMenuElementProps>
}> = ({ deviceKind, onDeviceSelected, className, disabled, label, selectMenuElement }) => {
  const [sources, setSources] = useState<MediaDeviceInfo[]>([])
  const [menuItems, setMenuItems] = useState<MenuItem[]>([])

  const listDevices = useCallback(async () => {
    const devices = await MediaDeviceManager.getDevices(deviceKind)
    setSources(devices)
    setMenuItems(
      devices.map((item) => {
        return { label: item.label, value: item.deviceId }
      })
    )
  }, [deviceKind])

  useEffect(() => {
    listDevices()
    navigator.mediaDevices.addEventListener('devicechange', listDevices)

    return () => {
      navigator.mediaDevices.removeEventListener('devicechange', listDevices)
    }
  }, [listDevices])

  if (sources.length <= 1 && !selectMenuElement) {
    return <></>
  }

  const onMenuItemSelected = (item: MenuItem) => {
    const device = sources.find((d) => d.label === item.label)
    device && onDeviceSelected(device)
  }

  return (
    <SelectButton
      disabled={disabled}
      className={className}
      buttonLabel={label}
      menuItems={menuItems}
      onMenuItemSelected={onMenuItemSelected}
      selectMenuElement={selectMenuElement}
    />
  )
}
