import { createSlice, PayloadAction } from '@reduxjs/toolkit'
import { RootState } from '../../app/store'
import { MediaDeviceModel } from './models'

const initialState: MediaDeviceModel = {
  selectedAudioDeviceId: null,
  selectedVideoDeviceId: null,
}

export const mediaDeviceSlice = createSlice({
  name: 'mediaDevice',
  initialState,
  reducers: {
    setSelectedAudioDeviceId: (state, action: PayloadAction<string | null>) => {
      state.selectedAudioDeviceId = action.payload
    },
    setSelectedVideoDeviceId: (state, action: PayloadAction<string | null>) => {
      state.selectedVideoDeviceId = action.payload
    },
  },
})

export const { setSelectedAudioDeviceId, setSelectedVideoDeviceId } = mediaDeviceSlice.actions

export const selectCurrentAudioDeviceId = (state: RootState) => state.mediaDevice.selectedAudioDeviceId

export const selectCurrentVideoDeviceId = (state: RootState) => state.mediaDevice.selectedVideoDeviceId

export default mediaDeviceSlice.reducer
